#ifndef INCLUDED_JNETD
#define INCLUDED_JNETD

#include "socketlb.h"
#include "mem.h"

typedef struct ServiceNetworkStatus_ {
   Socket *socket;
   int dgramfd;
} ServiceNetworkStatus;

typedef enum {
   BUILTIN_NONE, BUILTIN_ECHO, BUILTIN_DISCARD, BUILTIN_INFO,
   BUILTIN_GATEWAY
} Builtin;

enum {
   JNETD_DEFAULTMAXPID = 65536
};

/* Default configuration file */

#define JNETD_DEFAULTCFFILE "jnetd.cf"

/* Domain appened to the IP address for RBL checks */

/* Use the line below on a production box */
#define JNETD_RBLMAP "rbl.maps.vix.com"
/* Or the line below for local tests */
/* #define JNETD_RBLMAP "in-addr.arpa" */

#endif
